#####################
Numpy manual contents
#####################

.. toctree::

   user/index
   reference/index
   f2py/index
   dev/index
   neps/index
   release
   about
   bugs
   license
   glossary
